.. _built-ins-ref:

|Enaml| Built-in Widgets
===============================================================================

The following components are built into |Enaml| and available without import.

.. automodule:: enaml.widgets.combo_box
    :members:

.. class:: enaml.widgets.combo_box.ComboBox
..    :members:
